From 74a9a8edf04c7d35439e2c02ebe5872048ec4698 Mon Sep 17 00:00:00 2001
From: Johannes Meyer <johannes.meyer@icinga.com>
Date: Wed, 3 Jun 2020 15:59:53 +0200
Subject: [PATCH] modal.js: Request compact content with `showCompact`

---
 public/js/icinga/behavior/modal.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/public/js/icinga/behavior/modal.js b/public/js/icinga/behavior/modal.js
index 082b941b1..109e1053e 100644
--- a/public/js/icinga/behavior/modal.js
+++ b/public/js/icinga/behavior/modal.js
@@ -42,8 +42,8 @@
         var $modal = _this.$ghost.clone();
         var $urlTarget = _this.icinga.loader.getLinkTargetFor($a);
 
-        // Add view=compact, we don't want controls in a modal
-        url = _this.icinga.utils.addUrlParams(url, { 'view': 'compact' });
+        // Add showCompact, we don't want controls in a modal
+        url = _this.icinga.utils.addUrlFlag(url, 'showCompact');
 
         // Set the toggle's base target on the modal to use it as redirect target
         $modal.data('redirectTarget', $urlTarget);